@@ -57,11 +57,13 @@ uiSpatialImage <- function(csite, img_frmt) {
     absolutePanel(id = "timecontrol_sp", class = "panel panel-default", 
                 fixed = TRUE, draggable = TRUE, top = "auto", 
                 left = "auto", right = 20, bottom = 20,
-                width = 350, height = 110,  
+                width = 350, height = 140,  
                 
                 div(style = "margin-left: 15px; margin-top: 5px",
-                    sliderInput("timepoint_sp_idx", 
-                                label = paste0("Time: ", pasteAggLimit(csite$ui_attr$timepoints[csite$ui_attr$timepoint_sp_idx], csite$GWSDAT_Options$Aggby)),
+                    h4(textOutput("timepoint_sp_idx_label")),
+                    sliderInput("timepoint_sp_idx",
+                                label="",
+#                                label = paste0("Time: ", pasteAggLimit(csite$ui_attr$timepoints[csite$ui_attr$timepoint_sp_idx], csite$GWSDAT_Options$Aggby)),
                                 min = 1,
                                 max = length(csite$ui_attr$timepoints),
                                 step = 1,
